<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xsi:schemaLocation="http://www.w3.org/1999/XSL/Format fop.xsd ">

	<xsl:output method="xml" encoding="utf-8" indent="yes"/>

	<xsl:template match="/">
		<fo:root 	font-family="'Times New Roman', 'Times', serif"
					font-size="12pt"	>
			<fo:layout-master-set>
				<fo:simple-page-master master-name="A4"
					page-width="148mm" page-height="210mm" margin="1cm">
					<fo:region-body margin="16pt 0" />
					<fo:region-before extent="16pt" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="A4">
				<fo:static-content flow-name="xsl-region-before">
					<fo:block><xsl:value-of select="/document/title"/></fo:block>
				</fo:static-content>
				<fo:flow flow-name="xsl-region-body">
					<xsl:apply-templates />
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="p">
		<fo:block>
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="section">
		<fo:block-container page-break-after="always">
			<xsl:apply-templates />
		</fo:block-container>
	</xsl:template>

	<xsl:template match="document/title">
		<fo:block font-size="16pt" font-weight="bold" font-family="'Verdana', 'Arial', sans-serif"
				text-align="center" margin="12pt 0">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="section/title">
		<fo:block font-size="14pt" font-weight="bold" font-family="'Verdana', 'Arial', sans-serif"
				text-align="left" margin="12pt 0">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="entry">
		<fo:block	page-break-inside="avoid" text-indent="-3em" margin-left="3em">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>
	
	<xsl:template match="term">
		<fo:inline font-weight="bold">
			<xsl:apply-templates />
		</fo:inline>
	</xsl:template>

	<xsl:template match="description">
		<xsl:text> - </xsl:text>
		<fo:inline>
			<xsl:apply-templates />
		</fo:inline>
	</xsl:template>

	<xsl:template match="em">
		<fo:inline font-style="italic">
			<xsl:apply-templates />
		</fo:inline>
	</xsl:template>

	<xsl:template match="em/em">
		<fo:inline font-style="normal">
			<xsl:apply-templates />
		</fo:inline>
	</xsl:template>
	
	<xsl:template match="table">
		<fo:block-container margin="1em auto 2em auto">
		<fo:table>
			<xsl:apply-templates />
		</fo:table>
		<fo:block font-size="10pt">
			Table <xsl:value-of select="count(preceding::table)+1"/>. <xsl:apply-templates select="caption"/>
		</fo:block>
		</fo:block-container>
	</xsl:template>
	
	<xsl:template match="thead">
		<fo:table-header>
			<xsl:apply-templates />			
		</fo:table-header>
	</xsl:template>
	
	<xsl:template match="tfoot">
		<fo:table-footer>
			<xsl:apply-templates />			
		</fo:table-footer>
	</xsl:template>
	
	<xsl:template match="tbody">
		<fo:table-body>
			<xsl:apply-templates />			
		</fo:table-body>
	</xsl:template>
	
	<xsl:template match="tr">
		<fo:table-row>
			<xsl:apply-templates />			
		</fo:table-row>
	</xsl:template>
	
	<xsl:template match="td">
		<fo:table-cell border-style="solid"><fo:block>
			<xsl:apply-templates />			
		</fo:block></fo:table-cell>
	</xsl:template>
</xsl:stylesheet>
